@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import importlib
 import json
 import logging
 import os
@@ -7,7 +8,6 @@ from datetime import datetime
 
 from tornado.options import options
 
-from lesscode.utils.EsUtil import format_es_param_result
 from lesscode.utils.encryption_algorithm import AES
 
 
@@ -65,9 +65,13 @@ class EsHelper:
                                           track_total_hits=track_total_hits)
 
         result_list = []
+        try:
+            es_utils = importlib.import_module("lesscode_utils.es_utils")
+        except ImportError as e:
+            raise Exception(f"lesscode_utils is not exist,run:pip install lesscode_utils")
         for r in res["hits"]:
             result_list.append(
-                format_es_param_result(r, param_list, is_need_decrypt_oralce, is_need_es_score, route_key))
+                es_utils.format_es_param_result(r, param_list, is_need_decrypt_oralce, is_need_es_score, route_key))
         result_dict = {
             "data_count": res["total"]["value"],
             "data_list": result_list
@@ -288,10 +292,14 @@ class EsHelper:
                                          track_total_hits=track_total_hits)
         result_list = []
         data_count = 0
+        try:
+            es_utils = importlib.import_module("lesscode_utils.es_utils")
+        except ImportError as e:
+            raise Exception(f"lesscode_utils is not exist,run:pip install lesscode_utils")
         if res:
             for r in res["hits"]:
                 result_list.append(
-                    format_es_param_result(r, param_list, is_need_decrypt_oralce, is_need_es_score, route_key))
+                    es_utils.format_es_param_result(r, param_list, is_need_decrypt_oralce, is_need_es_score, route_key))
             data_count = res["total"]["value"]
         result_dict = {
             "data_count": data_count,
