@@ -11,12 +11,13 @@ from tornado.options import options
 
 from lesscode.db.redis.redis_helper import RedisHelper
 from lesscode.utils.json import JSONEncoder
+from threading import Thread
 
 
 # 装饰器
 
 
-def Cache(ex=3600 * 8, cache_key=None):
+def Cache(ex=3600 * 12, cache_key=None):
     def cache_func(func):
         # 默认key生成方法：str(item)
         @functools.wraps(func)
@@ -40,7 +41,7 @@ def deal_cache(func, ex, cache_key, *args, **params):
     func_name = str(func).split(" ")[1]
     if not cache_key:
         cache_key = format_insert_key(signature, func_name, args, params)
-    value = query_cache(cache_key)
+    value = query_cache(cache_key, params, ex, func=func, args=args)
     if value is not False:
         data = value
     else:
@@ -55,10 +56,20 @@ def deal_cache(func, ex, cache_key, *args, **params):
     return data
 
 
-def query_cache(cache_key, conn_name=None):
+def query_cache(cache_key, params=None, ex=3600 * 12, func=None, args=None, conn_name=None):
     if conn_name is None:
         conn_name = options.cache_conn
     if options.cache_enable:
+        ttl = RedisHelper(conn_name).get_connection(sync=True).ttl(cache_key)
+
+        if ttl and 0 < ttl <= 3600 * 11 + 2700:
+            Thread(target=request_interface, kwargs={
+                "func": func,
+                "params": params,
+                "args": args,
+                "ex": ex,
+                "cache_key": cache_key
+            }).start()
         data = RedisHelper(conn_name).sync_get(cache_key)
         if data:
             value = json.loads(data)
@@ -69,6 +80,12 @@ def query_cache(cache_key, conn_name=None):
     return False
 
 
+def request_interface(func, params, args, ex, cache_key):
+    copy_params = copy.deepcopy(params)
+    data = func(*args, **copy_params)
+    insert_cache(data, ex, cache_key)
+
+
 def format_insert_key(signature, func_name, args, params):
     _args = []
     param_keys = list(signature.parameters.keys())
