@@ -1,7 +1,9 @@
+import warnings
 from threading import Thread
 
 
 class MyThread(Thread):
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
 
     def __init__(self, target, *args, **kwargs):
         super(MyThread, self).__init__()
@@ -26,6 +28,7 @@ class MyThread(Thread):
 
 
 def thread_task(task_list: list):
+    warnings.warn("此方法已弃用，不推荐使用，切换到lesscode-utils包里", DeprecationWarning)
     thread_list = []
     for task in task_list:
         if isinstance(task, list):
